@@ -253,11 +253,33 @@ sub alias
 {
     my $self = shift;
 
-    return Fey::Table::Alias->new( table => $self, @_ );
+    my %p = @_ == 1 ? ( alias_name => $_[0] ) : @_;
+
+    return Fey::Table::Alias->new( table => $self, %p );
 }
 
 sub is_alias { 0 }
 
+sub aliased_column
+{
+    my $self   = shift;
+    my $prefix = shift;
+    my $name   = shift;
+
+    my $col = $self->column($name)
+        or return;
+
+    return $col->alias( alias_name => $prefix . $col->name() );
+}
+
+sub aliased_columns
+{
+    my $self   = shift;
+    my $prefix = shift;
+
+    return map { $self->aliased_column( $prefix, $_ ) } @_;
+}
+
 sub sql
 {
     return $_[1]->quote_identifier( $_[0]->name() );
@@ -403,14 +425,32 @@ column objects.
 
 =head2 $table->alias(%p)
 
+=head2 $table->alias($alias_name)
+
 This method returns a new C<Fey::Table::Alias> object based on the
 table. Any parameters passed to this method will be passed through to
 C<< Fey::Table::Alias->new() >>.
 
+As a shortcut, if you pass a single argument to this method, it will
+be passed as the "alias_name" parameter to C<<
+Fey::Table::Alias->new() >>.
+
 =head2 $table->is_alias()
 
 Always returns false.
 
+=head2 $table->aliased_column( $prefix, $column_name )
+
+This method returns a new L<Fey::Column::Alias> object. The alias's
+name is generated by concatenating the specified prefix and the
+column's real name.
+
+=head2 $table->aliased_columns( $prefix, @column_names )
+
+This method returns a list of new L<Fey::Column::Alias> objects. The
+alias names are generated by concatenating the specified prefix and
+the column's real name.
+
 =head2 $table->sql()
 
 =head2 $table->sql_with_alias()
